@@ -1,7 +1,7 @@
 barp<-function(height,width=0.4,names.arg=NULL,legend.lab=NULL,legend.pos=NULL,
  col=NULL,border=par("fg"),main=NULL,xlab="",ylab="",xlim=NULL,ylim=NULL,x=NULL,
  staxx=FALSE,staxy=FALSE,height.at=NULL,height.lab=NULL,cex.axis=par("cex.axis"),
- pch=NULL,cylindrical=FALSE,shadow=FALSE,do.first=NULL,ylog=FALSE,srt=NA) {
+ pch=NULL,cylindrical=FALSE,shadow=FALSE,do.first=NULL,ylog=FALSE,srt=NULL) {
 
  height.class<-attr(height,"class")
  if(!is.null(height.class)) {
@@ -38,16 +38,13 @@ barp<-function(height,width=0.4,names.arg=NULL,legend.lab=NULL,legend.pos=NULL,
    y=as.matrix(height))
  }
  if(is.null(xlim)) xlim<-range(x)+c(-0.6,0.6)
+ negy<-any(height<0,na.rm=TRUE)
  if(is.null(ylim)) {
-  negy<-any(height<0,na.rm=TRUE)
   if(negy) miny<-min(height,na.rm=TRUE)*1.05
   else miny<-ifelse(ylog,min(height)/10,0)
   ylim<-c(miny,max(height,na.rm=TRUE)*1.05)
  }
- else {
-  miny<-ylim[1]
-  negy<-miny<0
- }
+ else miny<-ylim[1]
  plot(ylim[1],type="n",main=main,xlab=xlab,ylab=ylab,axes=FALSE,xlim=xlim,
   ylim=ylim,xaxs="i",yaxs="i",log=ifelse(ylog,"y",""))
  if(!is.null(do.first)) eval(parse(text=do.first))
@@ -120,13 +117,14 @@ barp<-function(height,width=0.4,names.arg=NULL,legend.lab=NULL,legend.pos=NULL,
   }
  }
  if(!is.null(legend.lab)) {
-  xjust<-yjust<-0.5
+  xjust<-0
+  yjust<-1
   if(is.null(legend.pos)) {
-   cat("Click at the lower left corner of the legend\n")
+   cat("Click at the upper left corner of the legend\n")
    legend.pos<-locator(1)
-   xjust<-yjust<-0
   }
-  legend(legend.pos,legend=legend.lab,fill=col,xjust=xjust,yjust=yjust)
+  legend(list(x=legend.pos[1],y=legend.pos[2]),legend=legend.lab,
+   fill=col,xjust=xjust,yjust=yjust)
  }
  box()
  invisible(barpinfo)
